# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.3.2

([Full Changelog](https://github.com/voila-dashboards/voici/compare/@voila-dashboards/voici@0.3.1...db3b22a3d267337ee8dbded091948ac574588c66))

### Enhancements made

- Create `__main__.py` [#56](https://github.com/voila-dashboards/voici/pull/56) ([@jtpio](https://github.com/jtpio))

### Maintenance and upkeep improvements

- Troubleshoot CI [#55](https://github.com/voila-dashboards/voici/pull/55) ([@jtpio](https://github.com/jtpio))
- Update to `jupyterlite-core>=0.1.0,<0.2.0` [#50](https://github.com/voila-dashboards/voici/pull/50) ([@jtpio](https://github.com/jtpio))
- Use `ruff` instead of `flake8`, run `black` [#49](https://github.com/voila-dashboards/voici/pull/49) ([@jtpio](https://github.com/jtpio))

### Documentation improvements

- Create CONTRIBUTING.md [#52](https://github.com/voila-dashboards/voici/pull/52) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/voila-dashboards/voici/graphs/contributors?from=2023-03-23&to=2023-04-12&type=c))

[@jtpio](https://github.com/search?q=repo%3Avoila-dashboards%2Fvoici+involves%3Ajtpio+updated%3A2023-03-23..2023-04-12&type=Issues) | [@martinRenou](https://github.com/search?q=repo%3Avoila-dashboards%2Fvoici+involves%3AmartinRenou+updated%3A2023-03-23..2023-04-12&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.3.1

([Full Changelog](https://github.com/voila-dashboards/voici/compare/v0.3.0...9ff7f63d4c31d3562a0cfb8ba8e714c4bb7cce20))

### Maintenance and upkeep improvements

- Simplify the script for bumping versions [#47](https://github.com/voila-dashboards/voici/pull/47) ([@jtpio](https://github.com/jtpio))
- Remove the `reset_stable.sh` script [#45](https://github.com/voila-dashboards/voici/pull/45) ([@jtpio](https://github.com/jtpio))
- Update to Voila 0.5.0a3 [#44](https://github.com/voila-dashboards/voici/pull/44) ([@jtpio](https://github.com/jtpio))
- Update dev dependencies, TypeScript 5 [#42](https://github.com/voila-dashboards/voici/pull/42) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/voila-dashboards/voici/graphs/contributors?from=2023-03-22&to=2023-03-23&type=c))

[@jtpio](https://github.com/search?q=repo%3Avoila-dashboards%2Fvoici+involves%3Ajtpio+updated%3A2023-03-22..2023-03-23&type=Issues)

## 0.3.0

([Full Changelog](https://github.com/voila-dashboards/voici/compare/v0.2.0...49c441b4953d12135f84bee5f54869526ddfbef3))

### Enhancements made

- Add Voila config aliases [#33](https://github.com/voila-dashboards/voici/pull/33) ([@martinRenou](https://github.com/martinRenou))

### Bugs fixed

- Fix custom template support [#34](https://github.com/voila-dashboards/voici/pull/34) ([@martinRenou](https://github.com/martinRenou))

### Maintenance and upkeep improvements

- Update to `jupyterlite-core>=0.1.0b20` [#41](https://github.com/voila-dashboards/voici/pull/41) ([@jtpio](https://github.com/jtpio))
- Add `yarn watch` command to voici package [#39](https://github.com/voila-dashboards/voici/pull/39) ([@trungleduc](https://github.com/trungleduc))
- Expose the widget manager promise from the `VoiciApp` [#38](https://github.com/voila-dashboards/voici/pull/38) ([@jtpio](https://github.com/jtpio))
- Depend on `jupyterlite-core` [#37](https://github.com/voila-dashboards/voici/pull/37) ([@jtpio](https://github.com/jtpio))
- Test custom template in ui-tests [#35](https://github.com/voila-dashboards/voici/pull/35) ([@martinRenou](https://github.com/martinRenou))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/voila-dashboards/voici/graphs/contributors?from=2023-03-06&to=2023-03-22&type=c))

[@jtpio](https://github.com/search?q=repo%3Avoila-dashboards%2Fvoici+involves%3Ajtpio+updated%3A2023-03-06..2023-03-22&type=Issues) | [@martinRenou](https://github.com/search?q=repo%3Avoila-dashboards%2Fvoici+involves%3AmartinRenou+updated%3A2023-03-06..2023-03-22&type=Issues) | [@trungleduc](https://github.com/search?q=repo%3Avoila-dashboards%2Fvoici+involves%3Atrungleduc+updated%3A2023-03-06..2023-03-22&type=Issues)

## 0.2.0

([Full Changelog](https://github.com/voila-dashboards/voici/compare/@voila-dashboards/voici@0.2.1...96e793cfde26e39affbb9ea33cbc0223dd296829))

### Enhancements made

- Require latest voila [#31](https://github.com/voila-dashboards/voici/pull/31) ([@martinRenou](https://github.com/martinRenou))

### Documentation improvements

- Update README instructions [#32](https://github.com/voila-dashboards/voici/pull/32) ([@martinRenou](https://github.com/martinRenou))
- Minor edits to the README [#30](https://github.com/voila-dashboards/voici/pull/30) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/voila-dashboards/voici/graphs/contributors?from=2023-03-03&to=2023-03-06&type=c))

[@jtpio](https://github.com/search?q=repo%3Avoila-dashboards%2Fvoici+involves%3Ajtpio+updated%3A2023-03-03..2023-03-06&type=Issues) | [@martinRenou](https://github.com/search?q=repo%3Avoila-dashboards%2Fvoici+involves%3AmartinRenou+updated%3A2023-03-03..2023-03-06&type=Issues)

## 0.1.2

([Full Changelog](https://github.com/voila-dashboards/voici/compare/@voila-dashboards/voici@0.2.0...7b047500ec3c3aaa81b44fedc6946fb546d663cc))

### Bugs fixed

- Compute base_url as relative path [#27](https://github.com/voila-dashboards/voici/pull/27) ([@martinRenou](https://github.com/martinRenou))

### Maintenance and upkeep improvements

- UI-tests: test breadcrumbs click [#26](https://github.com/voila-dashboards/voici/pull/26) ([@martinRenou](https://github.com/martinRenou))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/voila-dashboards/voici/graphs/contributors?from=2023-03-03&to=2023-03-03&type=c))

[@martinRenou](https://github.com/search?q=repo%3Avoila-dashboards%2Fvoici+involves%3AmartinRenou+updated%3A2023-03-03..2023-03-03&type=Issues)

## 0.1.1

([Full Changelog](https://github.com/voila-dashboards/voici/compare/@voila-dashboards/voici@0.2.0-alpha.0...e829aa589743aa75d0e9be3902bf87a70a08ad2c))

### Bugs fixed

- Fix `voici build --contents notebooks/ --output-dir dist` use case [#25](https://github.com/voila-dashboards/voici/pull/25) ([@martinRenou](https://github.com/martinRenou))

### Maintenance and upkeep improvements

- More ui-tests [#23](https://github.com/voila-dashboards/voici/pull/23) ([@martinRenou](https://github.com/martinRenou))

### Documentation improvements

- Uncomment the "Getting Started" section in the README [#22](https://github.com/voila-dashboards/voici/pull/22) ([@martinRenou](https://github.com/martinRenou))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/voila-dashboards/voici/graphs/contributors?from=2023-03-02&to=2023-03-03&type=c))

[@martinRenou](https://github.com/search?q=repo%3Avoila-dashboards%2Fvoici+involves%3AmartinRenou+updated%3A2023-03-02..2023-03-03&type=Issues)

## 0.1.0

([Full Changelog](https://github.com/voila-dashboards/voici/compare/49c13dd07e3f37c5c5090e3bfa1139c392487530...5c82a5e40e9c2ca88001d8af49ba2c38be7bf4af))

### Enhancements made

- Turn into a JupyterLite Addon + support any kernel [#12](https://github.com/voila-dashboards/voici/pull/12) ([@martinRenou](https://github.com/martinRenou))

### Bugs fixed

- Playwright bot: Setup the micromamba env properly [#16](https://github.com/voila-dashboards/voici/pull/16) ([@martinRenou](https://github.com/martinRenou))

### Maintenance and upkeep improvements

- Debump versions so that the releaser can make 0.1.0 [#21](https://github.com/voila-dashboards/voici/pull/21) ([@martinRenou](https://github.com/martinRenou))
- Add releaser workflows to the repo [#15](https://github.com/voila-dashboards/voici/pull/15) ([@jtpio](https://github.com/jtpio))
- Pin on `yarn=1` in `environment.yml` for now [#14](https://github.com/voila-dashboards/voici/pull/14) ([@jtpio](https://github.com/jtpio))
- Add `publishConfig` to `package.json` [#13](https://github.com/voila-dashboards/voici/pull/13) ([@jtpio](https://github.com/jtpio))
- Simple UI tests [#10](https://github.com/voila-dashboards/voici/pull/10) ([@martinRenou](https://github.com/martinRenou))
- Update Github action workflows [#8](https://github.com/voila-dashboards/voici/pull/8) ([@martinRenou](https://github.com/martinRenou))

### Documentation improvements

- Add README [#18](https://github.com/voila-dashboards/voici/pull/18) ([@martinRenou](https://github.com/martinRenou))

### Other merged PRs

- Add bot for updating Playwright references [#9](https://github.com/voila-dashboards/voici/pull/9) ([@martinRenou](https://github.com/martinRenou))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/voila-dashboards/voici/graphs/contributors?from=2023-02-20&to=2023-03-02&type=c))

[@jtpio](https://github.com/search?q=repo%3Avoila-dashboards%2Fvoici+involves%3Ajtpio+updated%3A2023-02-20..2023-03-02&type=Issues) | [@martinRenou](https://github.com/search?q=repo%3Avoila-dashboards%2Fvoici+involves%3AmartinRenou+updated%3A2023-02-20..2023-03-02&type=Issues) | [@trungleduc](https://github.com/search?q=repo%3Avoila-dashboards%2Fvoici+involves%3Atrungleduc+updated%3A2023-02-20..2023-03-02&type=Issues)
